@@ -104,6 +104,8 @@ class S3Boto3Backend(duplicity.backend.Backend):
         self.bucket = self.s3.Bucket(self.bucket_name)  # only set if bucket is thought to exist.
 
     def _put(self, local_source_path, remote_filename):
+        from boto3.s3.transfer import TransferConfig  # pylint: disable=import-error
+
         if not self.s3:
             self.reset_connection()
 
@@ -136,6 +138,9 @@ class S3Boto3Backend(duplicity.backend.Backend):
             if config.s3_kms_grant:
                 extra_args[u'GrantFullControl'] = config.s3_kms_grant
 
+        transfer_config = TransferConfig(multipart_chunksize=config.s3_multipart_chunk_size,
+                                         multipart_threshold=config.s3_multipart_chunk_size)
+
         # Should the tracker be scoped to the put or the backend?
         # The put seems right to me, but the results look a little more correct
         # scoped to the backend.  This brings up questions about knowing when
@@ -146,6 +151,7 @@ class S3Boto3Backend(duplicity.backend.Backend):
         log.Info(u"Uploading %s/%s to %s Storage" % (self.straight_url, remote_filename, storage_class))
         self.s3.Object(self.bucket.name, key).upload_file(local_source_path.uc_name,
                                                           Callback=tracker.progress_cb,
+                                                          Config=transfer_config,
                                                           ExtraArgs=extra_args)
 
     def _get(self, remote_filename, local_path):
